@@ -1,10 +1,12 @@
 __all__ = [
     'base_controller',
-    'charges_controller',
-    'customers_controller',
     'subscriptions_controller',
+    'orders_controller',
     'plans_controller',
     'invoices_controller',
-    'orders_controller',
+    'customers_controller',
+    'charges_controller',
+    'recipients_controller',
     'tokens_controller',
+    'sellers_controller',
 ]
\ No newline at end of file
